@@ -1,6 +1,7 @@
 package Handel::L10N;
 use strict;
 use warnings;
+use utf8;
 use vars qw(@EXPORT_OK %Lexicon $handle);
 
 BEGIN {
@@ -29,7 +30,7 @@ Handel::L10N - Localization module for Handel
 
 =head1 VERSION
 
-    $Id: L10N.pm 20 2004-12-30 05:06:44Z claco $
+    $Id: L10N.pm 28 2004-12-31 02:09:27Z claco $
 
 =head1 SYNOPSIS
 
@@ -52,6 +53,9 @@ You can also export C<translate> into the users namespace:
 
     warn translate('My message');
 
+Thus far, the French trasnlation comes from Googles trasnlation tools.IF you
+have the time and can do better, the help would be much appreciated.
+
 =head1 METHODS
 
 =head2 C<translate>
@@ -72,3 +76,4 @@ L<Locale::Maketext>, L<Handel::L10N::us_en>, L<Handel::L10N::fr>
 
 
 
+
